@@ -2,14 +2,16 @@
 To determine if a file is executable we read the first few bytes of a file and
 check it against various signatures for different executable file formats.
 """
-import sys
 import inspect
+import sys
+
+from .async_utils import FileIO, run_coroutine
 
 
-def is_binary(filename):
-    """ Read the magic bytes from a file and determine if it is an executable
+async def aio_is_binary(filename):
+    """Read the magic bytes from a file and determine if it is an executable
     binary."""
-    signature = read_signature(filename)
+    signature = await read_signature(filename)
     for name, method in inspect.getmembers(
         sys.modules[__name__], predicate=inspect.isfunction
     ):
@@ -19,10 +21,14 @@ def is_binary(filename):
     return False
 
 
-def read_signature(filename, length=4):
+def is_binary(filename):
+    return run_coroutine(aio_is_binary(filename))
+
+
+async def read_signature(filename, length=4):
     """ Read the signature, first length bytes, from filename."""
-    with open(filename, "rb") as file_handle:
-        return file_handle.read(length)
+    async with FileIO(filename, "rb") as file_handle:
+        return await file_handle.read(length)
 
 
 def check_elf(_filename, signature):
