@@ -17,10 +17,7 @@ def html_print_mode(
 
     root = os.path.dirname(os.path.abspath(__file__))
     templates_dir = os.path.join(root, "print_mode")
-    templates_env = Environment(
-        loader=FileSystemLoader(templates_dir),
-        autoescape=select_autoescape(["html"]),
-    )
+    templates_env = Environment(loader=FileSystemLoader(templates_dir))
 
     temp_showcase = "templates/showcase.html"
     temp_content = "templates/content.html"
