@@ -15,10 +15,10 @@ package_test_data = [
     #    "product": "gimp",
     #    "version": "2.8.22",
     # },
-    {
-        "url": "https://mirrors.edge.kernel.org/centos/6/os/x86_64/Packages/",
-        "package_name": "gimp-2.6.9-9.el6.x86_64.rpm",
-        "product": "gimp",
-        "version": "2.6.9",
-    },
+    # {
+    #    "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
+    #    "package_name": "gimp-2.8.22-1.el7.x86_64.rpm",
+    #    "product": "gimp",
+    #    "version": "2.8.22",
+    # },
 ]
