@@ -7,8 +7,8 @@ mapping_test_data = [
 ]
 package_test_data = [
     {
-        "url": "https://kojipkgs.fedoraproject.org/packages/qt/3.3.8/10.fc9/x86_64/",
-        "package_name": "qt-3.3.8-10.fc9.x86_64.rpm",
+        "url": "https://kojipkgs.fedoraproject.org//vol/fedora_koji_archive00/packages/qt3/3.3.8b/13.fc9/src/",
+        "package_name": "qt3-3.3.8b-13.fc9.src.rpm",
         "product": "qt",
         "version": "3.3.8",
     },
